1
0
mirror of https://git.FreeBSD.org/ports.git synced 2025-01-06 06:30:19 +00:00
freebsd-ports/math/rkward-kde4/files/patch-rkward_rbackend_rkrbackend.cpp
Thierry Thomas 3fe34cbcab Add a missing patch.
Reported by:	pointyhat via Pav
Feature safe:	yes
2011-11-18 17:24:45 +00:00

17 lines
829 B
C++

--- rkward/rbackend/rkrbackend.cpp.orig 2011-10-18 10:29:11.000000000 +0200
+++ rkward/rbackend/rkrbackend.cpp 2011-11-12 22:08:00.000000000 +0100
@@ -1056,11 +1056,11 @@
if (backend_was_forked) return;
backend_was_forked = true;
// Block SIGCLD in the main thread from now on. I don't fully understand, why, but otherwise, these signals
// interrupt the select() call in the fork()ing code of library(parallel)
sigset_t new_set;
sigemptyset (&new_set);
- sigaddset (&new_set, SIGCLD);
+ sigaddset (&new_set, SIGCHLD);
pthread_sigmask (SIG_BLOCK, &new_set, NULL);
// This was used to show a warning message. Unfortunately, however, forks also occur on every popen (i.e. in system(..., intern=TRUE).
@@ -1056,11 +1056,11 @@
if (backend_was_forked) return;
backend_was_forked = true;
- // Block SIGCLD in the main thread from now on. I don't fully understand, why, but otherwise, these signals
+ // Block SIGCHLD in the main thread from now on. I don't fully understand, why, but otherwise, these signals
// interrupt the select() call in the fork()ing code of library(parallel)
sigset_t new_set;